#
# spec file for package python-jwcrypto
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jwcrypto
Version:        0.7
Release:        lp152.1.1
Summary:        Python module package implementing JOSE Web standards
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/latchset/jwcrypto
Source:         https://files.pythonhosted.org/packages/source/j/jwcrypto/jwcrypto-%{version}.tar.gz
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography
BuildArch:      noarch
%python_subpackages

%description
A Python implementation of the JOSE Working Group documents:
RFC 7515 - JSON Web Signature (JWS)
RFC 7516 - JSON Web Encryption (JWE)
RFC 7517 - JSON Web Key (JWK)
RFC 7518 - JSON Web Algorithms (JWA)
RFC 7519 - JSON Web Token (JWT)
RFC 7520 - Examples of Protecting Content Using JSON Object Signing and Encryption (JOSE)

%prep
%setup -q -n jwcrypto-%{version}

%build
%python_build

%install
%python_install
rm -rv %{buildroot}%{_datadir}/doc/jwcrypto
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand py.test-%{$python_bin_suffix} jwcrypto

%files %{python_files}
%{python_sitelib}/*
%license LICENSE
%doc README.md

%changelog
* Mon Mar 30 2020 Michael Ströder <michael@stroeder.com>
- update to upstream release 0.7.0
  * Allow to use JWKSet on a JWT with no KID
  * Fixed JWE jose_header
  * Added JWE/JWS custom registry header implementation
  * RFC 8037 - Support for Ed25519, Ed448
  * Stricter OKP key generation parms check
  * Add X25519/X448 support
  * Simplify internal code curve selection
  * Fix encoding length of EC keys Coordinates
  * Add the ability to verify 'none' signatures
  * Import ABC from collections.abc instead of collections for Python 3.9 compatibility
* Fri Mar 22 2019 Michael Ströder <michael@stroeder.com>
- update to upstream release 0.6.0
  * Use python-cryptography's AES key wrapping
  * Add tests for key wrapping where CEK < KEK
  * Fix ECDH-ES key exchange for CEK greater than KEK
  * Add support for RFC7797
  * Fix JWK.from_json
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jun 27 2018 michael@stroeder.com
- update to upstream release 0.5.0:
  * Better validation of JWE
  * Avoid deprecation warnings
  * Tested to work with python 3.7
* Mon Jun 25 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Aug  3 2017 michael@stroeder.com
- update to upstream release 0.4.2
* Mon Jul 24 2017 michael@stroeder.com
- update to upstream release 0.4.1
* Sat Dec  3 2016 michael@stroeder.com
- update to upstream release 0.4.0
* Fri Nov 11 2016 michael@stroeder.com
- initial package of upstream release 0.3.1
